@@ -1,7 +1,7 @@
 ;;; generic-x.el --- A collection of generic modes
 
 ;; Copyright (C) 1997, 1998, 2002, 2003, 2004,
-;;   2005 Free Software Foundation, Inc.
+;;   2005, 2006 Free Software Foundation, Inc.
 
 ;; Author:  Peter Breton <pbreton@cs.umb.edu>
 ;; Created: Tue Oct 08 1996
@@ -435,7 +435,7 @@ like an INI file.  You can add this hook to `find-file-hook'."
 (define-generic-mode reg-generic-mode
   '(?\;)
   '("key" "classes_root" "REGEDIT" "REGEDIT4")
-  '(("\\(\\[.*]\\)"          1 font-lock-constant-face)
+  '(("\\(\\[.*\\]\\)"        1 font-lock-constant-face)
     ("^\\([^\n\r]*\\)\\s-*=" 1 font-lock-variable-name-face))
   '("\\.[rR][eE][gG]\\'")
   (list
@@ -1729,6 +1729,8 @@ like an INI file.  You can add this hook to `find-file-hook'."
     "reiserfs"
     "romfs"
     "smbfs"
+    "cifs"
+    "usbdevfs"
     "sysv"
     "tmpfs"
     "udf"
@@ -1740,7 +1742,7 @@ like an INI file.  You can add this hook to `find-file-hook'."
     "swap"
     "auto"
     "ignore")
-  '(("^\\([/-A-Za-z0-9_]+\\)\\s-+\\([/-A-Za-z0-9_]+\\)"
+  '(("^\\([^# \t]+\\)\\s-+\\([^# \t]+\\)"
      (1 font-lock-type-face t)
      (2 font-lock-variable-name-face t)))
   '("/etc/[v]*fstab\\'")
@@ -1748,7 +1750,7 @@ like an INI file.  You can add this hook to `find-file-hook'."
    (function
     (lambda ()
       (setq imenu-generic-expression
-	    '((nil "^\\([/-A-Za-z0-9_]+\\)\\s-+" 1))))))))
+	    '((nil "^\\([^# \t]+\\)\\s-+" 1))))))))
 
 ;; From Jacques Duthen <jacques.duthen@sncf.fr>
 (when (memq 'show-tabs-generic-mode generic-extras-enable-list)
@@ -1771,7 +1773,8 @@ like an INI file.  You can add this hook to `find-file-hook'."
   ;; XEmacs change: s/:weight bold/:bold t/
   '((((class grayscale) (background light)) (:background "DimGray"   :bold t))
     (((class grayscale) (background dark))  (:background "LightGray" :bold t))
-    (((class color)     (min-colors 88))    (:background "red1"))
+    ;; XEmacs change: we don't have `min-colors'
+    ;(((class color)     (min-colors 88))    (:background "red1"))
     (((class color))                        (:background "red"))
     (t (:bold t)))
   "Font Lock mode face used to highlight TABs."
@@ -1783,7 +1786,8 @@ like an INI file.  You can add this hook to `find-file-hook'."
   ;; XEmacs change: s/:weight bold/:bold t/
   '((((class grayscale) (background light)) (:background "DimGray"   :bold t))
     (((class grayscale) (background dark))  (:background "LightGray" :bold t))
-    (((class color)     (min-colors 88))    (:background "yellow1"))
+    ;; XEmacs change: we don't have `min-colors'
+    ;(((class color)     (min-colors 88))    (:background "yellow1"))
     (((class color))                        (:background "yellow"))
     (t (:bold t)))
   "Font Lock mode face used to highlight spaces."
