@@ -1,7 +1,7 @@
 ;;; vc-rcs.el --- support for RCS version-control
 
 ;; Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000,
-;;   2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+;;   2001, 2002, 2003, 2004, 2005, 2006 Free Software Foundation, Inc.
 
 ;; Author:     FSF (see vc.el for full credits)
 ;; Maintainer: Andre Spiegel <spiegel@gnu.org>
@@ -153,8 +153,11 @@ For a description of possible values, see `vc-check-master-templates'."
                 (vc-file-setprop file 'vc-checkout-model 'locking))))
           state)
       (if (not (vc-mistrust-permissions file))
+          ;; XEmacs change: no 2nd arg to `file-attributes'
           (let* ((attributes  (file-attributes file))
                  (owner-uid   (nth 2 attributes))
+                 (owner-name  (or (user-login-name owner-uid)
+                                  (number-to-string owner-uid)))
                  (permissions (nth 8 attributes)))
             (cond ((string-match ".r-..-..-." permissions)
                    (vc-file-setprop file 'vc-checkout-model 'locking)
@@ -163,7 +166,7 @@ For a description of possible values, see `vc-check-master-templates'."
 		   (if (eq (vc-checkout-model file) 'locking)
 		       (if (file-ownership-preserved-p file)
 			   'edited
-			 (vc-user-login-name owner-uid))
+			 owner-name)
 		     (if (vc-rcs-workfile-is-newer file)
 			 'edited
 		       'up-to-date)))
@@ -819,7 +822,7 @@ file."
             'needs-patch))
 	 ;; locked by the calling user
 	 ((and (stringp locking-user)
-	       (string= locking-user (vc-user-login-name)))
+	       (string= locking-user (vc-user-login-name file)))
 	  (if (or (eq (vc-checkout-model file) 'locking)
 		  workfile-is-latest
 		  (vc-rcs-latest-on-branch-p file workfile-version))
@@ -908,7 +911,8 @@ Returns: nil            if no headers were found
 	  (vc-file-setprop file 'vc-state
 			   (cond
 			    ((eq locking-user 'none) 'up-to-date)
-			    ((string= locking-user (vc-user-login-name)) 'edited)
+			    ((string= locking-user (vc-user-login-name file)) 
+                             'edited)
 			    (t locking-user)))
 	  ;; If the file has headers, we don't want to query the
 	  ;; master file, because that would eliminate all the
