@@ -1,7 +1,7 @@
 ;;; vc-sccs.el --- support for SCCS version-control
 
 ;; Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000,
-;;   2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+;;   2001, 2002, 2003, 2004, 2005, 2006 Free Software Foundation, Inc.
 
 ;; Author:     FSF (see vc.el for full credits)
 ;; Maintainer: Andre Spiegel <spiegel@gnu.org>
@@ -108,7 +108,7 @@ For a description of possible values, see `vc-check-master-templates'."
               (if (vc-workfile-unchanged-p file)
                   'up-to-date
                 'unlocked-changes)
-            (if (string= locking-user (vc-user-login-name))
+            (if (string= locking-user (vc-user-login-name file))
                 'edited
               locking-user)))
       'up-to-date)))
@@ -122,15 +122,18 @@ For a description of possible values, see `vc-check-master-templates'."
       ;; We have to be careful not to exclude files with execute bits on;
       ;; scripts can be under version control too.  Also, we must ignore the
       ;; group-read and other-read bits, since paranoid users turn them off.
-      (let* ((attributes (file-attributes file))
-             (owner-uid  (nth 2 attributes))
+      ;; XEmacs change: no 2nd arg to `file-attributes'
+      (let* ((attributes  (file-attributes file))
+             (owner-uid   (nth 2 attributes))
+             (owner-name  (or (user-login-name owner-uid)
+                              (number-to-string owner-uid)))
              (permissions (nth 8 attributes)))
 	(if (string-match ".r-..-..-." permissions)
             'up-to-date
           (if (string-match ".rw..-..-." permissions)
               (if (file-ownership-preserved-p file)
                   'edited
-                (vc-user-login-name owner-uid))
+                owner-name)
             ;; Strange permissions.
             ;; Fall through to real state computation.
             (vc-sccs-state file))))
