@@ -46,14 +46,14 @@
         nil)
       file)))
 
-;; These two are present in XEmacs >= 21.5
+;; These three are present in XEmacs >= 21.5
 (unless (fboundp 'line-end-position)
   (defalias 'line-end-position 'point-at-eol))
 (unless (fboundp 'line-beginning-position)
   (defalias 'line-beginning-position 'point-at-bol))
-
 (unless (fboundp 'line-number-at-pos)
-  (defalias 'line-number-at-pos 'line-number))
+  (defun line-number-at-pos (&optional pos)
+    (line-number pos t)))
 
 (unless (fboundp 'subst-char-in-string)
   (defun subst-char-in-string (fromchar tochar string &optional inplace)
